@@ -1,4 +1,4 @@
-#!D:\bld\digital_rf_1590951609565\_h_env\python.exe
+#!D:\bld\digital_rf_1591043993231\_h_env\python.exe
 # ----------------------------------------------------------------------------
 # Copyright (c) 2017 Massachusetts Institute of Technology (MIT)
 # All rights reserved.
@@ -154,7 +154,7 @@ class DataPlotter(object):
             sti_psd_data = np.zeros([self.control.num_fft, self.control.bins], np.float)
             sti_times = np.zeros([self.control.bins], np.complex128)
 
-            for b in np.arange(self.control.bins):
+            for b in np.arange(self.control.bins, dtype=np.int_):
 
                 if self.control.verbose:
                     print(
@@ -205,21 +205,15 @@ class DataPlotter(object):
 
             # determine image color extent in log scale units
             Pss = sti_psd_data
-            vmin = np.real(np.median(Pss) - 6.0)
-            vmax = np.real(
-                np.median(Pss) + (np.max(Pss) - np.median(Pss)) * 0.61803398875 + 50.0
-            )
 
             if self.control.zaxis:
                 vmin = int(self.control.zaxis.split(":")[0])
                 vmax = int(self.control.zaxis.split(":")[1])
             else:
-                vmin = np.real(np.median(Pss) - 6.0)
-                vmax = np.real(
-                    np.median(Pss)
-                    + (np.max(Pss) - np.median(Pss)) * 0.61803398875
-                    + 50.0
-                )
+                med_Pss = np.nanmedian(Pss)
+                max_Pss = np.nanmax(Pss)
+                vmin = np.real(med_Pss - 6.0)
+                vmax = np.real(med_Pss + (max_Pss - med_Pss) * 0.61803398875 + 50.0)
 
             im = ax.imshow(
                 sti_psd_data,
@@ -237,7 +231,10 @@ class DataPlotter(object):
             # plot dates
 
             tick_spacing = np.arange(
-                self.control.bins / 8, self.control.bins, self.control.bins / 8
+                self.control.bins / 8,
+                self.control.bins,
+                self.control.bins / 8,
+                dtype=np.int_,
             )
             ax.set_xticks(tick_spacing)
             tick_labels = []
